@@ -1,5 +1,5 @@
 /* This file is part of the yazpp toolkit.
- * Copyright (C) 1998-2008 Index Data and Mike Taylor
+ * Copyright (C) 1998-2009 Index Data and Mike Taylor
  * See the file LICENSE for details.
  */
 
@@ -143,7 +143,7 @@ Zlint_code Zlint_test_search_01::sendTest(Zlint *z)
         {
             z->msg_check_for("sort %s", try_sort[m_sort_no]);
 
-            char *setstring = "default";
+            const char *setstring = "default";
             int len;
             Z_SortRequest *sr = apdu->u.sortRequest;
             
@@ -278,6 +278,7 @@ Zlint_code Zlint_test_search_01::recv_fail(Zlint *z, int reason)
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
